#
# spec file for package gitolite
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         gitolite_homedir    /srv/gitolite
%define         git_user            git
Name:           gitolite
Version:        3.6.13
Release:        2.5
Summary:        Server for git directory version tracker
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
URL:            http://gitolite.com
Source0:        https://github.com/sitaramc/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
Source11:       README.SUSE
Provides:       group(%{git_user})
Provides:       user(%{git_user})
BuildRequires:  git
Requires:       git
Conflicts:      gitosis
BuildArch:      noarch
%if 0%{?suse_version} >= 1330
Requires(pre):  user(wwwrun)
Requires(pre):  user(nginx)
%endif
%{perl_requires}

%description
Gitolite is an access control layer on top of git, which allows access control
down to the branch level, including specifying who can and cannot rewind a given
branch.

%prep
%setup -q
install -m 644 %{SOURCE11} .

%build

%install
install -d %{buildroot}%{gitolite_homedir}
install -d %{buildroot}%{gitolite_homedir}/.ssh
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{perl_vendorlib}
install -d %{buildroot}%{_datadir}/%{name}

cp -pr src/lib/Gitolite %{buildroot}%{perl_vendorlib}
echo "%{version}" >src/VERSION
cp -a src/* %{buildroot}%{_datadir}/%{name}
ln -s %{_datadir}/%{name}/%{name} %{buildroot}%{_bindir}/%{name}

# empty authorized_keys file
touch %{buildroot}%{gitolite_homedir}/.ssh/authorized_keys

%pre
# Create user and group on the system if necessary
# default group: git
getent group %{git_user} >/dev/null || \
	%{_sbindir}/groupadd -r %{git_user}

# default user: git
getent passwd %{git_user} >/dev/null || \
	%{_sbindir}/useradd -c "git repository hosting" \
	-d %{gitolite_homedir} -G %{git_user} -g %{git_user} \
	-r -s /bin/bash %{git_user}

# if apache user is not in git group, add it
getent passwd wwwrun >/dev/null &&
	%{_sbindir}/usermod -a -G git wwwrun

# if nginx user is not in git group, add it
getent passwd nginx >/dev/null &&
	%{_sbindir}/usermod -a -G git nginx

%files
%license COPYING
%doc README.markdown CHANGELOG README.SUSE
%{_bindir}/*
%{perl_vendorlib}/*
%{_datadir}/%{name}
%attr(750,%{git_user},%{git_user}) %dir %{gitolite_homedir}
%attr(750,%{git_user},%{git_user}) %dir %{gitolite_homedir}/.ssh
%config(noreplace) %attr(640,%{git_user},%{git_user}) %{gitolite_homedir}/.ssh/authorized_keys

%changelog
* Sun Feb  4 2024 Benoît Monin <benoit.monin@gmx.fr>
- add user/group provides for rpm 4.19
- drop conditional against obsolete suse 11.1
* Fri Jul 21 2023 Dirk Müller <dmueller@suse.com>
- update to 3.6.13:
  * remove the "description" file on new repos, to fix a bug
    created by an optimisation made 6 years ago in 3.6.8 (and
    was caught only in 2022 or so!)
* Wed Feb  3 2021 chris@computersalat.de
- fix for boo#1181130
  * add nginx to group git
* Sun Dec 20 2020 Dirk Müller <dmueller@suse.com>
- update to 3.6.12:
  * mirroring terminoligy changes
  * install script can now modify #! lines when using a custom
  * 'config' user command allows for config values with spaces
  * finally added notes in "t/README" on testing http mode and
* Mon Jul  1 2019 chris@computersalat.de
- update changes file
  * add missing info about bugzilla 1096814
* Mon Jan 14 2019 chris@computersalat.de
- update to 3.6.11
  - fix for boo#1121570 (CVE-2018-20683)
    security issue in 'rsync' (bundle helper); see commit 5df2b81 for more
- update to 3.6.10
  - fix up boo-boo caused by previous release; see mails on list for details
* Thu Sep 13 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from descriptions.
* Thu Sep 13 2018 Karol Babioch <kbabioch@suse.com>
- Update to 3.6.9:
  * CVE-2018-16976: prevent racy access to repos in process of migration to
    gitolite (bsc#1108272)
  * 'info' learns new '-p' option to show only physical repos (as opposed to
    wild repos)
- Update to 3.6.8:
  * fix bug when deleting *all* hooks for a repo
  * allow trailing slashes in repo names
  * make pre-receive hook driver bail on non-zero exit of a pre-receive hook
  * allow templates in gitolite.conf (new feature)
  * various optimiations
- Applied spec-cleaner
* Mon Jun  4 2018 Neal Gompa <ngompa13@gmail.com>
- Update to 3.6.7 (fix for boo#1096814)
  * allow repo-specific hooks to be organised into
    subdirectories, and allow the multi-hook driver to be
    placed in some other location of your choice
  * allow simple test code to be embedded within the
    gitolite.conf file; see contrib/utils/testconf for how.
    (This goes on the client side, not on the server)
  * allow syslog "facility" to be changed, from the default of
    'local0'
  * allow syslog "facility" to be changed, from the default of
    replaced with a space separated list of members
- 2016-09-08  v3.6.6
  * simple but important fix for a future perl deprecation
    (perl will be removing "." from @INC in 5.24)
  * 'perms' now requires a '-c' to activate batch mode
    (should not affect interactive use but check your scripts
    perhaps?)
  * gitolite setup now accepts a '-m' option to supply a
    custom message (useful when it is used by a script)
* Mon Mar 20 2017 kukuk@suse.de
- Require system user wwwrun
* Tue Jan 17 2017 bwiedemann@suse.com
- dont include rebuild counter in rpm to make build-compare happy
* Mon Jan  2 2017 jengelh@inai.de
- Do not suppress errors from useradd/groupadd
- Replace unknown "groupmod -A" call by "usermod -a -G".
* Thu Sep  8 2016 tampakrap@opensuse.org
- change the homedir of the git user to /srv/gitolite, to prevent ownership
  conflicts of the /srv/git directory with the git-daemon package
* Mon Aug  8 2016 chris@computersalat.de
- fix changes file
  * add missing ChangeLog info
* Fri Jul 29 2016 rpm@fthiessen.de
- Update to 3.6.5
  * allow creator check to be bypassed during mirroring
  * handle new style ssh fingerprinting correctly
    (thanks to Robin Johnson)
  * allow pre-auto-gc as a repo-specific hook
  * optimise mirror pushes for heavily used repos
  * create-with-reference trigger: on repo creation, setup
    objects/info/alternates for a server side alternate object store.
  * 'mirror status all all' prints a list of repos that have *some*
    error, which is arguably more useful for further action/processing
  * allow incrementally adding more repo-specific hooks
- 2015-11-01  v3.6.4
  * a ref-create bug in wild repos was fixed
  * some contrib code related to AD integration, and to redmine user
    aliases
  * teach Alias.pm a few new tricks
  * remove a race condition in 'create' command that affected the
    'default roles' setting
  * make 'who-pushed' more efficient (local push logs, and
    'tip search')
  * 'gitolite query-rc' learns '-d' ('--dump') option
* Sun May 17 2015 tampakrap@opensuse.org
- Change URL to gitolite.com
- Use full URL path for the source tarball
- Add Git as runtime dependency, it's heavily needed
* Sun Apr 26 2015 rpm@fthiessen.de
- Update to 3.6.3
  * allow limited use of 'git config' using the new 'config' command
  * accept openssh 6.8's new fingerprint output format
  * (finally!) allow limited symlinks within ~/repositories; see
    commit 8e36230 for details
  * perms command now lists available roles
  * minor backward compat breakage: 'perms -l repo' no longer works;
    see 'perms -h' for new usage
  * allow gitolite-shell to be used as $SHELL (experts only; no
    support, no docs; see commit 9cd1e37 for details)
  * help with 'git push --signed' using a post-receive hook to adopt
    push certs into 'refs/push-certs'; for details see
    contrib/hooks/repo-specific/save-push-signatures
  * new 'transparent proxy' feature for git repos; see
    src/lib/Gitolite/Triggers/TProxy.pm for details
* Mon Oct  6 2014 darin@darins.net
- update to 3.6.1
- updated and renamed README.SUSE
- removed patches and unused files
- spec cleanup
* Mon Oct 22 2012 chris@computersalat.de
- fix for bnc#784983
  * add subpkg skel
  - hold files needed for git user homedir (/etc/skelgit/....)
  * rework spec pre section
* Sat Aug 11 2012 chris@computersalat.de
- update to 2.3.1
  - fix bug where config statements would get ignored if you had a
    description set. The biggest problem was that this would affect
    mirroring.
  - for mor info please see the CHANGELOG file
- rebase patches
- fix License: GPL-2.0 -> GPL-2.0+
- add skeldir
  * add .gitolite.rc to skeldir
- add README.SuSE
* Wed Dec 14 2011 chris@computersalat.de
- update to 1.5.9.1
  * IMPORTANT SECURITY FIX; PLEASE UPGRADE IF YOU'RE USING
    SOMETHING OLDER THAN THIS ONE
  - supercool new 'git' adc; so cool it's disabled by default
  - '-prune' added to find commands; makes a big diff if REPO_BASE is
    NFS/CIFS mounted
  - first python ADC contributed -- 'perms' makes setperms etc easier
    to do
  - 'set-head' ADC added
  - v2.0rc1; major refactor
* Thu Nov 10 2011 dmueller@suse.de
- change requires to git-daemon
* Tue Feb 15 2011 chris@computersalat.de
- improve co-operation with git-web
  o add gitweb patch
  o add permissions file to doc
  o add apache user to git group
* Mon Feb 14 2011 chris@computersalat.de
- update to version 1.5.9
  - Nokia MeeGo team contributed ldap scripts
  - large configs should now be twice as fast (except when gl-perms exists)
    due to my finding and eliminating a wasted parse_acl
  - major change: split the config file when in big-config mode
    (includes a data format change)
  - GL_ALL_READ_ALL to make things much, (MUCH!) faster for sites where all
    can read all repos (like Fedora)
  - rc file revamp -- was getting too big and unwieldy; now the documentation
    is in a new file instead of inline
  - allow gitolite to be used even when users have real IDs (thus $HOME is not
    valid to find the rc file); allow /etc/gitolite/gitolite.rc then
  - BIG one for adc writers -- full blown access checks (ref level) can be
    done from an ADC now (though it has to be in perl, not shell)!
  - allow full access checks from perl (shell can only do level 1 checks);
    useful in hooks or ADCs
- v1.5.8
  - Jeff from KDE contributed the watch ADC
  - allow disabling gitolite (write access only) to take backups
  - document how to move gitolite from one server to another
  - custom permissions categories (default being READERS and WRITERS) for
    setperms (thanks to Jeff from KDE for the idea/need)
- noarch pkg, not only for suse > 1110
- reworked rpm-system patch
- add group/user git
* Thu Dec 16 2010 asn@cynapses.org
- Initial package version 1.5.7
